@@ -47,41 +47,78 @@ class TPsimplex:
         self.do_write=write
         self.file_name=file_name
         self.error=False
+        self.msg=""
         self.__check_equation()
         #return self.Optimal_Solution()
 
 
     def __check_equation(self):
 
-        if self.number_of_constrains!=len(self.equation):
-            raise ValueError("Number of Constrains does not match with given number of equations ")
+        if str(type(self.equation)) != "<class 'list'>":
+            self.msg = '\nList required, found {0}'.format(str(type(self.equation)))
+            self.error = True
+            return
+
+        elif self.number_of_constrains!=len(self.equation):
+            self.msg="\nNumber of Constrains does not match with given number of equations "
+            self.error=True
+            return
+
         elif self.optimize_fn is None:
-            raise AssertionError("Optimize_equation cannot be null")
+            self.msg="\nOptimize_equation cannot be null"
+            self.error=True
+            return
+
         elif len(self.optimize_fn)!=self.number_of_variables:
-            raise ValueError('Length of coefficient in optimize function must be equal to number of variables\n'
-                             'i.e if any coefficient having 0 coefficient, mention it as 0 instead of leaving that '
-                             'blank in proper order')
+            self.msg='\nLength of coefficient in optimize function must be equal to number of variables\ni.e if any coefficient having 0 coefficient, mention it as 0 instead of leaving that blank in proper order'
+            self.error=True
+            return
+
         elif str(type(self.optimize_type))!="<class 'str'>":
-            raise TypeError("Optimize_type must me string, given {0}".format(type(self.optimize_type)))
+            self.msg="\nOptimize_type must me string, given {0}".format(type(self.optimize_type))
+            self.error=True
+            return
+
         elif (self.optimize_type!='max') and (self.optimize_type!='min'):
-            raise ValueError("Optimize_type must be either 'max'(Maximation) or 'min'(Minimization) type only")
+            self.msg="\nOptimize_type must be either 'max'(Maximation) or 'min'(Minimization) type only"
+            self.error=True
+            return
 
         for i in self.equation:
             if str(type(i))!="<class 'list'>":
-                raise TypeError('List required, found {0}'.format(str(type(i))))
+                self.msg='\nList required, found {0}'.format(str(type(i)))
+                self.error=True
+                return
+
             elif len(i)==0:
-                raise AssertionError('Coefficient of equation cannot be null')
+                self.msg='\nCoefficient of equation cannot be null'
+                self.error=True
+                return
+
             elif len(i)!=self.number_of_variables+2:
-                raise ValueError('Inappropriate Equation found, please provide the equation in the given format \n'
-                                 'i.e [Coefficient_of_variables,"Inequality",RHS_Coefficient_of_equation]')
+                self.error=True
+                self.msg='\nInappropriate Equation found, please provide the equation in the given format \ni.e [Coefficient_of_variables,"Inequality",RHS_Coefficient_of_equation]'
+                return
+
             elif str(type(i[self.number_of_variables]))!="<class 'str'>":
-                raise ValueError('Inequality must be string in given equation found {0}'.format(str(type(i[self.number_of_variables+1]))))
+                self.msg='\nInequality must be string in given equation found {0}'.format(str(type(i[self.number_of_variables+1])))
+                self.error=True
+                return
+
             elif i[self.number_of_variables] not in ['<=','>=','=']:
-                raise ValueError("Only '<=','>=','=' type of inequality is allowed found {0}".format(i[self.number_of_variables]))
+                self.msg="\nOnly '<=','>=','=' type of inequality is allowed found {0}".format(i[self.number_of_variables])
+                self.error=True
+                return
 
         if self.do_write and self.file_name==None:
-            raise ValueError("File name is required if the the write is set to true")
-        self.__make_new_variables()
+            self.msg="\nFile name is required if the the write is set to true"
+            self.error=True
+            return
+        if not self.error :
+            self.__make_new_variables()
+        else:
+            return
+
 
 
     def __make_new_variables(self):
@@ -101,8 +138,14 @@ class TPsimplex:
                 additional_varialbe[k].append(0)
             k+=1
 
+        count = 0
+        for i in self.equation:
+            for j in i:
+                if j == '>=':
+                    count += 1
+
         k=0
-        p=0
+        num = 0
         for i in self.equation:
             coeff_variable.append([])
             var = 1
@@ -116,9 +159,16 @@ class TPsimplex:
                     basic_variable.append('S' + str(k + 1))
                     opti_F.append(0)
                 elif j=='>=':
-                    for l in range(p):
-                        coeff_variable[k].append(0)
+                    #for l in range(p):
+                        #coeff_variable[k].append(0)
+                    #coeff_variable[k].append(-1)
+                    num+=1
+                    if num > 1:
+                        for i in range(num - 1):
+                            coeff_variable[k].append(0)
                     coeff_variable[k].append(-1)
+                    for i in range(count - num):
+                        coeff_variable[k].append(0)
                     opti_F.insert(k,0)
                     opti_F.append(-1)
                     additional_varialbe[k].pop(k)
@@ -128,8 +178,6 @@ class TPsimplex:
                     basic_variable.append('A' + str(k + 1))
                     self.artificial_var.append('A' + str(k + 1))
 
-                    p+=1
-
                 elif j=='=':
                     additional_varialbe[k].pop(k - 1)
                     additional_varialbe[k].insert(k, 1)
@@ -208,7 +256,10 @@ class TPsimplex:
         print('\r')
         for i in whole_matrix:
             for j in i:
-                print(j, end='  ')
+                try:
+                    print(round(j,3), end='  ')
+                except:
+                    print(j, end='  ')
             print('\r')
 
         if self.do_write:
@@ -222,8 +273,10 @@ class TPsimplex:
 
             for i in whole_matrix:
                 for j in i:
-
-                    file.write(str(j))
+                    try:
+                        file.write(str(round(j,3)))
+                    except:
+                        file.write(str(j))
                     file.write('\t')
 
                 file.write('\n')
@@ -276,9 +329,9 @@ class TPsimplex:
             print(self.basic_var[p],end='\t')
             for j in i:
                 if j>=0:
-                    print(" "+str(j),end='\t')
+                    print(" "+str(round(j,3)),end='\t')
                 elif j<0:
-                    print(j,end='\t')
+                    print(round(j,3),end='\t')
             p+=1
             print()
 
@@ -295,10 +348,10 @@ class TPsimplex:
                 file.write('\t\t')
                 for j in i:
                     if j >= 0:
-                        file.write(" "+str(j))
+                        file.write(" "+str(round(j,3)))
                         file.write('\t\t')
                     elif j < 0:
-                        file.write(str(j))
+                        file.write(str(round(j,3)))
                         file.write('\t\t')
                 p += 1
                 file.write('\n')
@@ -461,8 +514,7 @@ class TPsimplex:
         temp_list2=[]
         if(self.leaving_indx==None):
             self.error=True
-            #print("\n\nLooks like we are not getting any leaving varible, please traceback to see the problem. If you find this solution wrong please raise an issue at:\nhttps://github.com/Ashish2000L/linear_programing")
-            #self.Optimal_Solution()
+            self.msg="\nUnbounded solution found!"
             return False
 
 
@@ -481,19 +533,18 @@ class TPsimplex:
         k=temp_list2[self.leaving_indx]
         for i,v in enumerate(self.main_matrix[self.leaving_indx]):
             if i!=self.entering_indx:
-                self.main_matrix[self.leaving_indx][i]=round(float(v/k),3)
+                self.main_matrix[self.leaving_indx][i]=float(v/k)
         temp_leav_val_list=self.main_matrix[self.leaving_indx]
         for i,v in enumerate(self.main_matrix):
             if i!=self.leaving_indx:
                 m=temp_list2[i]*-1
                 for k,j in enumerate(v):
                     if k !=self.entering_indx:
-                        self.main_matrix[i][k]=float(format(j+(m*temp_leav_val_list[k]),'.5f'))
+                        self.main_matrix[i][k]=float(j+(m*temp_leav_val_list[k]))
         self.itr+=1
         print('\n\nITERATION {0}\n'.format(self.itr))
         self.__print_matrix(msg='ITERATION '+str(self.itr))
 
-        #self.Optimal_Solution()
 
 
     def __process_simplex_phase_2(self):
@@ -559,7 +610,7 @@ class TPsimplex:
                 if j==i[1]:
                     k=F[i[0]]*-1
                     for x,y in enumerate(v):
-                        F[x]=round(F[x]+(y*k),3)
+                        F[x]=F[x]+(y*k)
 
         self.main_matrix[0]=F
 
@@ -583,17 +634,22 @@ class TPsimplex:
             if self.main_matrix[0][ln]>0:
                 print("\n\n\nSOLUTION\n")
                 self.__print_matrix(msg='SOLUTION')
-                final_solution=[['F',self.main_matrix[0][ln]]]
+                final_solution=[['F',round(self.main_matrix[0][ln],3)]]
 
                 cost_coeff_var=['X'+str(i+1) for i in range(self.number_of_variables)]
-                for i,v in enumerate(self.basic_var):
 
+                inserted_var=[]
+                for i,v in enumerate(self.basic_var):
                     if v in cost_coeff_var:
-                        final_solution.append([v,self.main_matrix[i][ln]])
+                        final_solution.append([v,round(self.main_matrix[i][ln],3)])
+                        inserted_var.append(v)
+
+                for i in cost_coeff_var:
+                    if i not in inserted_var:
+                        final_solution.append([i,round(0,3)])
 
                 return np.asarray(final_solution)
             else:
-                return "Either No Fisible solution or an error occured!"
-                #return "\nEither the equation have not fisible solution or an error occured.\n Please staceback to look for the issue, if you find this solution wrong you can create an issue here: \n https://github.com/Ashish2000L/linear_programing"
+                return "No Fisible solution found!!"
         else:
-            return "Looks like Either No optimal Solution Exist or there is an error, Please check manually!"
+            return self.msg
\ No newline at end of file
